<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category template manager
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 26, 2013 11:36:11 AM
 * @version $Rev$
 */

/**
 * Settings class
 * Used to generate an WP administration tab to view a list of apply buffers/
 */
class Admin_Taxonomies_Translator extends WP_Page {

    protected $interfacer = null;

    public function __construct() {
        $this->interfacer = WP_Interfacer::getInstance();
    }

    public function getCapability() {
        return WP_Constants::CAPABILITY_ADMIN;
    }

    public function getMenuSlug() {
        return 'carerix_taxonomies_translator_page';
    }

    public function getMenuTitle() {
        return 'Translations';
    }

    public function getPageTitle() {
        return 'Translations';
    }

    public function page() {
        unset($_POST['submit']);

        $categories = array(
            'general.header.publications',
            'general.header.candidates'
        );

        $input_data = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
        if (is_array($input_data) && wp_verify_nonce($input_data['_carerix_nonce_field'], 'taxonomies')) {
            foreach ($input_data as $key => $value) {
                if (stripos($key, 'resource_category') === 0) {
                    $old_value = $this->getCategoryValueFromResourceString($key);
                    $cat_id = get_cat_ID(htmlentities($old_value));

                    if ($cat_id) {
                        wp_update_term($cat_id, 'category', array('name' => $value));
                    }
                }

                Environment_Settings::_set_setting_unique($key, $value);
            }
        }
        $data = array();
        $languages = array_keys((false === $wpml = $this->interfacer->get_wpml_active_languages()) ? array() : $wpml );
        $currentLanguage = $this->interfacer->language_major_current();

        if ($languages != FALSE) {
            $data['headerLanguages'] = $languages;
        } else {
            $data['headerLanguages'] = array($currentLanguage);
        }

        $labelKeys = array(
            '1|general.message.field.country' => 'publications',
            '2|general.message.field.region' => 'publications',
            '3|general.header.education' => 'publications',
            '3.1|CxPortal.message.field.sector' => 'publications',
            '3.2|CxPortal.message.field.industry' => 'publications',
            '4|CxPortal.header.functionGroups' => 'publications',
            '5|CxPortal.message.field.workLocation' => 'publications',
            '5.1|CxPortal.message.field.procedure' => 'publications',
            '6|general.message.field.country' => 'candidate',
            '7|general.message.field.region' => 'candidate',
            '8|general.header.educationLevel_1' => 'candidate',
            '9|general.header.educationLevel_2' => 'candidate',
            '10|general.header.educationLevel_3' => 'candidate',
            '12|CxPortal.message.field.contractType' => 'publications',
            '13|CxPortal.message.field.weekWorkHours' => 'publications',
            '14|CxPortal.message.field.minSalary' => 'publications',
            '15|CxPortal.message.field.maxSalary' => 'publications',
        );

        $rows = array();
        $labels = Utils_Labels::get();
        foreach ($labelKeys as $labelKey => $section) {
            $_t = explode('|', $labelKey);
            $labelKey = $_t[1];
            $extra = '';
            $resourceKey = $labelKey;
            if (stripos($labelKey, '_') !== FALSE) {
                $_labelKey = explode('_', $labelKey);
                $resourceKey = $_labelKey[0];
                $extra = $_labelKey[1];
            }

            $fields = array();
            $name = "resource_taxonomy_{$section}_{$labelKey}";
            $fields['label'] = $labels[$resourceKey] . ' ' . $extra;
            $fields['section'] = $section;
            $fields['inputs'] = array();

            foreach ($data['headerLanguages'] as $language) {
                $currLabels = Utils_Labels::get($language);
                $key = $name . '_' . $language;
                $key = str_replace('.', '_', $key);

                $value = Environment_Settings::_setting_get($key);
                if (!$value)
                    $value = $currLabels[$resourceKey];

                $input = array('name' => $key, 'value' => $value);
                array_push($fields['inputs'], $input);
            }
            array_push($rows, $fields);
        }



        foreach ($categories as $category) {
            $catkey = str_replace('.', '_', $category);
            $fields = array();
            $fields['label'] = $labels[$category];
            $fields['section'] = 'Categories';
            $fields['inputs'] = array();

            $name = "resource_category_{$catkey}";
            foreach ($data['headerLanguages'] as $language) {
                $currLabels = Utils_Labels::get($language);
                $key = $name . '_' . $language;
                $value = Environment_Settings::_setting_get($key);
                if (!$value)
                    $value = $currLabels[$category];
                $input = array('name' => $key, 'value' => $value);

                array_push($fields['inputs'], $input);
            }
            array_push($rows, $fields);
        }

        //$data['categoryRows'] = $categoryRows;
        $data['rows'] = $rows;
        $template = new Utils_Template('admin/taxonomies/translator');
        $template->with($data)->display();
    }

    private function getCategoryValueFromResourceString($category) {

        $value = Environment_Settings::_setting_get($category);
        if (!$value) {
            $parts = explode('_', $category);
            $language = array_pop($parts);
            $category = implode('.', $parts);
            $currLabels = Utils_Labels::get($language);
            $value = $currLabels[$category];
        }
        return $value;
    }

}
