<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 29, 2013 9:29:42 AM
 * @version $Rev$
 */

/**
 * Job class
 * Used to ....
 */
class Entity_Writer_Job extends Entity_Writer {
	
	protected $type = WP_Constants::ENTITY_TYPE_JOB;
	protected $fragment = '';
	protected $categoryLanguage = false;
    protected $categoryKey = 'Publications';
    private $sourceData = array();
	
	public function getContent() 
	{
        $content = '';
        $labels = array();

        if(isset($this->dataDictionary['medium'])) {
            $_l = explode('-', $this->dataDictionary['medium']);
            if(isset($_l[1])) {
                $language = trim($_l[1]);
                
                $language .= '-' . strtoupper($language);
                $labels = Utils_Labels::get($language);

            } else {
                $labels = Utils_Labels::get();
            }
        } else {
            $labels = Utils_Labels::get($this->categoryLanguage);
        }
		
		$contentSections = array(
			'introInformation', 'companyInformation', 'vacancyInformation',
			'requirementsInformation', 'offerInformation', 'functionContactInformation',
            'publicationEnd', 'applicationContactInformation'
		);
		
		$labelKeysForSection = array(
			'introInformation' => 'CxPortal.message.field.introduction',
			'companyInformation' => 'CxPortal.message.field.organization',
			'vacancyInformation' => 'CxPortal.message.field.function',
			'requirementsInformation' => 'CxPortal.message.field.requirements',
			'offerInformation' => 'CxPortal.message.field.offer',
			'functionContactInformation' => 'CxPortal.message.field.information',
			'applicationContactInformation' => 'CxPortal.message.field.application',
			'publicationEnd' => 'CxPortal.message.field.closingDate',
		);
		
		$sourceData = $this->getSourceData();
        $header = @$sourceData['settings']['header'];
        $footer = @$sourceData['settings']['footer'];


		$set = false;
		foreach($this->dataDictionary as $section => $value)
		{
			if(! in_array($section, $contentSections) )
			{
				continue;
			}
			
			$label_key = $labelKeysForSection[$section];
			$section_name = $labels[$label_key];
			$css_class = "cx2_" . @strtolower(@end(@explode(".", $label_key)));
			
			$content .= "<h4 class='cx_h4 $css_class'>$section_name</h4> <div class='$css_class'>$value</div> ";
			
			if(!$set)
			{
				$this->fragment = $content;
				$content .= '<!--more-->';
				$set = true;
			}
		}

        if(strlen(trim($header)) > 0) {
            $content = $header . $content;
        }

		/**
		 * [cx_apply_button] shortcode is not mandatory anymore in Sources->Source edit->Publication Details Footer
		 *
		 * @since 2.20.1
		 */
        if(strlen(trim($footer)) <= 0) {
            // $footer = '[cx_apply_button]';
            $footer = '';
        }
        
        if(strlen(trim($footer)) > 0) {
            $content =  $content .$footer;
        }
        
		return $content;
	}

	public function getTitle() 
	{
        $title = '';
		if(isset($this->dataDictionary['title']))
		{
			$title = $this->dataDictionary['title'];
		}
		elseif(isset($this->dataDictionary['titleInformation']))
		{
			$title =$this->dataDictionary['titleInformation'];
		}
        
		return $title;
	}
	
	public function getCorrespondentID()
	{

		if(isset($this->dataDictionary['guid']))
		{
			return $this->dataDictionary['guid'];
		}
		if(isset($this->dataDictionary['publicationID']))
		{
			return $this->dataDictionary['publicationID'];
		}
		
		return false;
	}
	
	public function getPublishDate()
	{
		if(isset($this->dataDictionary['pubDate']))
		{
			return $this->dataDictionary['pubDate'];
		}
		if(isset($this->dataDictionary['publicationStart']))
		{
			return $this->dataDictionary['publicationStart'];
		}
		
		return false;
	}
	
    public function postWrite($post_id) {
        $categoryLanguage = $this->categoryLanguage;
        if(!$categoryLanguage) $categoryLanguage = $this->interfacer->language_major_current();
        
        if(trim($this->dataDictionary['medium']) == 'web') {
            $labels = Utils_Labels::get($this->categoryLanguage);
            $resource = 'resource_category_'. str_replace('.', '_', 'general.header.publications');
            $categoryKey = Environment_Settings::_setting_get($resource . '_' . $categoryLanguage);

            if(!$categoryKey) {
                $categoryKey = $labels['general.header.publications'];
            }
        } else {
            $categoryKey = trim($this->dataDictionary['medium']);
        }
        
        $categories = array();
        
//        if (isset($this->dataDictionary['branche0'])) {
//            $categories[] = $this->dataDictionary['branche0'];
//        }
//        if (isset($this->dataDictionary['branche1'])) {
//            $categories[] = $this->dataDictionary['branche1'];
//        }
        if (isset($this->dataDictionary['function0'])) {
            $categories[] = $this->dataDictionary['function0'];
        }
        if (isset($this->dataDictionary['function1'])) {
            $categories[] = $this->dataDictionary['function1'];
        }
        if (isset($this->dataDictionary['toWorkLevelNode'])) {
            $categories[] = $this->dataDictionary['toWorkLevelNode'];
        }
        
        if (Environment_Settings::getSkipMainCategory() !== 'on') {
            array_unshift($categories, $categoryKey);
        }
                
        $this->interfacer->entity_link_category($post_id, $categories, $this->categoryLanguage);
        
        // tags from function level, region, location
        $tags = array_filter( array(
            @$this->dataDictionary['category'], 
            @$this->dataDictionary['workLocation'],
            @$this->dataDictionary['country1'],
            @$this->dataDictionary['region1'],
            @$this->dataDictionary['country2'],
            @$this->dataDictionary['region2'],
            @$this->dataDictionary['country3'],
            @$this->dataDictionary['region3'],
        ));
        // tags from requiredInfo
        
        $requiredEducations = @$this->dataDictionary['requiredEducations'];
        $retags = array();
        if(is_array($requiredEducations)) {
            
            foreach($requiredEducations as $requiredEducation) {
                $_e = array_filter(explode(':|:', $requiredEducation));
                $_e = array_map('trim', $_e);
                $retags = array_merge($retags, $_e);
            }
        }
        $tags = array_merge($retags, $tags);
        $tags = array_filter($tags);

        $this->interfacer->entity_set_tags($post_id, $tags);
        
        //$this->interfacer->entity_set_taxonomy($taxonomy_name, $entity_id, $taxonomies);
        $countries = array_filter(array(@$this->dataDictionary['country1'],@$this->dataDictionary['country2'], @$this->dataDictionary['country3']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_COUNTRY,$post_id, $countries);
        
        $regions = array_filter(array(@$this->dataDictionary['region1'], @$this->dataDictionary['region2'], @$this->dataDictionary['region3']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_REGION,$post_id, $regions);
        
        $workLocations = array_filter(array( @$this->dataDictionary['workLocation']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_WORKLOCATION, $post_id, $workLocations);
        
        /* $function = array_filter(array( @$this->dataDictionary['category']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_FUNCTION, $post_id, $function);*/
        
        $sector = array_filter(array( @$this->dataDictionary['branche0']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_SECTOR, $post_id, $sector);
        
        $industry = array_filter(array( @$this->dataDictionary['branche1']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_INDUSTRY, $post_id, $industry);

        $functiongroup = array_filter(array( @$this->dataDictionary['function0']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_FUNCTIONGROUP, $post_id, $functiongroup);

        $function = array_filter(array( @$this->dataDictionary['function1']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_FUNCTION, $post_id, $function);
        
        $worklevel = array_filter(array( @$this->dataDictionary['toWorkLevelNode']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_WORKLEVEL, $post_id, $worklevel);
        
        $procedure = array_filter(array(@$this->dataDictionary['procedure']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_PROCEDURE, $post_id, $procedure);

	    $contractType = array_filter(array(@$this->dataDictionary['contractType']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_CONTRACTTYPE, $post_id, $contractType);

	    $hoursPerWeek = array_filter(array(@$this->dataDictionary['hoursPerWeek']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_HOURSPERWEEK, $post_id, $hoursPerWeek);

	    $minSalary = array_filter(array(@$this->dataDictionary['minSalary']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_MINSALARY, $post_id, $minSalary);

	    $maxSalary = array_filter(array(@$this->dataDictionary['maxSalary']));
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_MAXSALARY, $post_id, $maxSalary);

        $educations = array_filter(@$this->dataDictionary['educations']);
        foreach($educations as $education) {
            $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_EDUCATION, $post_id, $education);
        }

	    $pubIdList = @$this->dataDictionary['pubIdList'];
	    $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_PUBIDLIST, $post_id, $pubIdList);


	    $medium = trim($this->dataDictionary['medium']);
        $this->interfacer->entity_set_property($post_id, 'medium', $medium);
        
        if(isset($this->dataDictionary['introInformation']) && strlen(trim($this->dataDictionary['introInformation'])) > 0) {
            $meta_desc = trim($this->dataDictionary['introInformation']);
            $this->interfacer->entity_set_property($post_id, '_yoast_wpseo_metadesc', $meta_desc);
        }
	}
	
	public function getFragment($post_id)
	{
        $labels = Utils_Labels::get();
		$link = $this->interfacer->get_post_permalink($post_id);
		$content  = "<h2 class='cx_h2'><a href='$link'>".$this->getTitle()."</a></h2>";
		$content .= $this->fragment ;
        $content .= '<a href="' . $link .'">'.$labels['general.actionLink.readMore'].' &raquo; </a>';
		return $content;
	}
	
	public function setCategoryLanguage($language) {
		$this->categoryLanguage = $language;
	}
    
    public function setCategoryKey($category) {
        $this->categoryKey = $category;
    }

    public function setSourceData($sourceData) {
        $this->sourceData = $sourceData;
    }
    
    public function getSourceData()
    {
        return $this->sourceData;
    }

    /**
     * Allow the slug of the job post to change according to its title
     * @return title
     */
    public function getSlug() {
        $title = $this->getTitle();
        return sanitize_title(JTransliteration::transliterate($title));
    }

}